package com.muyu.aliyun.bailian;

import com.muyu.aliyun.bailian.data.UploadFileModel;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Component;

import java.io.BufferedInputStream;
import java.io.DataOutputStream;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
@Component
@Log4j2
public class TemporaryStorage {

    public static void uploadFile(UploadFileModel uploadFileModel) {
        HttpURLConnection connection = null;
        try {
            // 创建URL对象
            URL url = new URL(uploadFileModel.getPreSignedUrl());
            connection = (HttpURLConnection) url.openConnection();

            // 设置请求方法用于文档上传，需与您在上一步中调用ApplyFileUploadLease接口实际返回的Data.Param中Method字段的值一致
            connection.setRequestMethod(uploadFileModel.getMethod());

            // 允许向connection输出，因为这个连接是用于上传文档的
            connection.setDoOutput(true);

            connection.setRequestProperty("X-bailian-extra", uploadFileModel.getBailianExtra());
            connection.setRequestProperty("Content-Type", uploadFileModel.getContentType());

            // 读取文档并通过连接上传
            try (DataOutputStream outStream = new DataOutputStream(connection.getOutputStream());
                 FileInputStream fileInputStream = new FileInputStream(uploadFileModel.getFilePath())) {
                byte[] buffer = new byte[4096];
                int bytesRead;

                while ((bytesRead = fileInputStream.read(buffer)) != -1) {
                    outStream.write(buffer, 0, bytesRead);
                }

                outStream.flush();
            }

            // 检查响应
            int responseCode = connection.getResponseCode();
            if (responseCode == HttpURLConnection.HTTP_OK) {
                // 文档上传成功处理
                log.info("File uploaded successfully");
            } else {
                // 文档上传失败处理
                log.error("Failed to upload the file. ResponseCode: " + responseCode);
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
        }
    }

    public static void uploadFileLink(UploadFileModel uploadFileModel) {
        HttpURLConnection connection = null;
        try {
            // 创建URL对象
            URL url = new URL(uploadFileModel.getPreSignedUrl());
            connection = (HttpURLConnection) url.openConnection();

            // 设置请求方法用于文档上传，需与您在上一步中调用ApplyFileUploadLease接口实际返回的Data.Param中Method字段的值一致
            connection.setRequestMethod(uploadFileModel.getMethod());

            // 允许向connection输出，因为这个连接是用于上传文档的
            connection.setDoOutput(true);

            connection.setRequestProperty("X-bailian-extra", uploadFileModel.getBailianExtra());
            connection.setRequestProperty("Content-Type", uploadFileModel.getContentType());

            URL sourceUrl = new URL(uploadFileModel.getSourceUrlString());
            HttpURLConnection sourceConnection = (HttpURLConnection) sourceUrl.openConnection();

            // 设置访问OSS的请求方法为GET
            sourceConnection.setRequestMethod("GET");
            // 获取响应码，200表示请求成功
            int sourceFileResponseCode = sourceConnection.getResponseCode();
            if (sourceFileResponseCode != 200){
                throw new RuntimeException();
            }
            // 从OSS读取文档并通过连接上传
            if (sourceFileResponseCode != HttpURLConnection.HTTP_OK){
                throw new RuntimeException("Failed to get source file.");
            }
            try (DataOutputStream outStream = new DataOutputStream(connection.getOutputStream());
                 InputStream in = new BufferedInputStream(sourceConnection.getInputStream())) {
                byte[] buffer = new byte[4096];
                int bytesRead;

                while ((bytesRead = in.read(buffer)) != -1) {
                    outStream.write(buffer, 0, bytesRead);
                }

                outStream.flush();
            }

            // 检查响应
            int responseCode = connection.getResponseCode();
            if (responseCode == HttpURLConnection.HTTP_OK) {
                // 文档上传成功
                System.out.println("File uploaded successfully.");
            } else {
                // 文档上传失败
                System.out.println("Failed to upload the file. ResponseCode: " + responseCode);
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
        }
    }

}
